OC.L10N.register(
    "contacts",
    {
    "Contacts" : "連絡先",
    "All contacts" : "すべての連絡先",
    "Details" : "詳細",
    "A contacts app for Nextcloud" : "Nextcloud の連絡先アプリ",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud の連絡先アプリは、 Nextcloud の CardDAV サーバーのユーザーインターフェースです。 さまざまなデバイスの連絡先を Nextcloud で簡単に同期し、オンラインで編集できます。\n\n*🚀**他の Nextcloud アプリケーションとの統合！**現在、メールとカレンダー - 今後の予定です。\n*🎉**誕生日を忘れないでください！**あなたの Nextcloud カレンダーで誕生日やその他の定期的なイベントを同期できます。\n*👥** 連絡先の共有！**あなたの友達や同僚とあなたの連絡先を共有したいですか？ 問題ない！\n*🙈**私たちは車輪を再発明していません！**偉大でオープンな SabreDAV ライブラリをベースにしています。",
    "Add new property" : "新しいプロパティを追加する",
    "Choose property type" : "プロパティの種類を選択",
    "Add a new picture" : "画像を追加",
    "Upload a new picture" : "新しい写真をアップロードする",
    "Choose from files" : "ファイルから選択",
    "Delete picture" : "画像を削除",
    "Download picture" : "画像をダウンロード",
    "Image is too big (max 1MB)." : "画像容量が大きすぎます (最大1 MB)",
    "No contact selected" : "連絡先が選択されていません",
    "Select a contact on the list to begin" : "開始するには、リストの連絡先を選択してください",
    "Loading" : "読み込み中",
    "Name" : "名前",
    "Company" : "会社",
    "Title" : "タイトル",
    "Download" : "ダウンロード",
    "Delete" : "削除",
    "This contact is not yet synced. Edit it to save it to the server." : "この連絡先はまだ同期されていません。 それを編集してサーバーに保存して下さい。",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "この連絡先は読み取り専用モードです。 この連絡先を編集する権限がありません。",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "編集しようとした連絡先が変更されました。 連絡先を手動で更新してください。 それ以上の編集は破棄されます。",
    "Addressbook" : "アドレス帳",
    "Groups" : "グループ",
    "New contact" : "新しい連絡先",
    "Importing {total} contacts into" : "連絡先を {total} にインポートしています",
    "Open your browser console for more details" : "詳細はブラウザコンソールを開きます",
    "Select type" : "タイプを選択",
    "Select Date" : "日付を選択",
    "Add contact in group" : "グループに連絡先を追加",
    "No results" : "該当なし",
    "Select option" : "オプションを選択",
    "Rename" : "名前を変更",
    "Enabled" : "有効",
    "Disabled" : "無効",
    "Copied" : "コピーしました",
    "Can not copy" : "コピーできません",
    "Copy link" : "リンクをコピー",
    "Enabled toggle of addressbook was not successful." : "アドレス帳の有効なトグルが成功しませんでした。",
    "Deletion of addressbook was not successful." : "アドレス帳の削除に失敗しました。",
    "Renaming of addressbook was not successful." : "アドレス帳の名前を変更できませんでした。",
    "Addressbook copied to clipboard" : "アドレス帳をクリップボードにコピー",
    "Addressbook was not copied to clipboard." : "アドレス帳はクリップボードにコピーされませんでした。",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num} 個のエンティティと共有"],
    "Share with users or groups" : "ユーザーまたはグループと共有する",
    "No users or groups" : "ユーザーまたはグループはありません",
    "can edit" : "編集を許可",
    "Unable to delete the share." : "共有を解除できません。",
    "Unable to change permissions." : "権限を変更できません。",
    "Importing into" : "インポート",
    "Import into" : "インポート",
    "Importing is disabled because there are no address books available" : "使用可能なアドレス帳がないため、インポートは無効です",
    "Address book name" : "アドレス帳名",
    "An error occurred, unable to create the addressbook." : "エラーが発生し、アドレス帳を作成できません。",
    "First name" : "名",
    "Last name" : "姓",
    "Display name" : "表示名",
    "Sort by {sorting}" : "{sorting} で整列",
    "Contact not found" : "連絡先がありません",
    "Nickname" : "ニックネーム",
    "Detailed name" : "詳細名",
    "Additional names" : "ミドルネーム",
    "Prefix" : "プレフィックス",
    "Suffix" : "サフィックス",
    "Notes" : "ノート",
    "Website" : "ウェブサイト",
    "Federated Cloud ID" : "クラウド共有ID",
    "Home" : "自宅",
    "Work" : "職場",
    "Other" : "その他",
    "Address" : "アドレス",
    "Post office box" : "私書箱",
    "Extended address" : "拡張アドレス",
    "City" : "市町村",
    "State or province" : "州／県",
    "Postal code" : "郵便番号",
    "Country" : "国名",
    "Birthday" : "誕生日",
    "Anniversary" : "記念日",
    "Date of death" : "命日",
    "Email" : "メール",
    "Instant messaging" : "インスタントメッセージ",
    "Phone" : "電話番号",
    "Mobile" : "携帯",
    "Work mobile" : "職場携帯",
    "Home mobile" : "個人携帯",
    "Fax" : "FAX",
    "Fax home" : "自宅FAX",
    "Fax work" : "職場FAX",
    "Pager" : "ポケベル",
    "Voice" : "音声番号",
    "Car" : "自動車",
    "Work pager" : "ワークページャー",
    "Social network" : "ソーシャルネットワーク",
    "The url of the profile. e.g. https://www.facebook.com/Nextclouders/ " : "プロフィールのURL。 例えば https://www.facebook.com/Nextclouders/",
    "Relationship" : "つながり",
    "Specify a relationship between you and the entity represented by this vCard." : "あなたとこのvCardが表すエンティティとの間の関係を指定します。",
    "Spouse" : "配偶者",
    "Child" : "子供",
    "Mother" : "母親",
    "Father" : "父親",
    "Parent" : "両親",
    "Brother" : "兄弟",
    "Sister" : "姉妹",
    "Relative" : "親族",
    "Friend" : "友人",
    "Colleague" : "同僚",
    "Manager" : "マネージャー",
    "Assistant" : "アシスタント",
    "Related" : "関連する",
    "Specify a relationship between another entity and the entity represented by this vCard." : "別のエンティティとこのvCardが表すエンティティとの間の関係を指定します。",
    "Contact" : "連絡先",
    "Agent" : "エージェント",
    "Emergency" : "緊急",
    "Co-worker" : "同僚",
    "Gender" : "性別",
    "Female" : "女性",
    "Male" : "男性",
    "An error occurred" : "エラーが発生しました"
},
"nplurals=1; plural=0;");
